#!/usr/bin/env node
const express = require("express");
const cors = require("cors");
const chalk = require("chalk");
const https = require("https");
const yargs = require("yargs/yargs");
const { hideBin } = require("yargs/helpers");

const defaultConfig = require("./config.json");
const createDevProxyMiddleware = require("./createDevProxyMiddleware");
const { getCredentials } = require("./utils");

const argv = yargs(hideBin(process.argv))
    .option("port", { alias: "p", describe: "Port that proxy will listen on" })
    .option("host", { alias: "h", describe: "Host for the proxy" })
    .option("https", {
        alias: "secure",
        describe: "Run proxy on https (see docs https://www.npmjs.com/package/@twilio/flex-ui-dev-proxy)"
    })
    .option("apiServiceUrl", { alias: "api", describe: "The endpoing to which the requests will be proxied to" })
    .default(defaultConfig).argv;

const app = express();

app.use(cors({ origin: true, credentials: true }));

// Proxy endpoints
app.use("/", createDevProxyMiddleware(argv.apiServiceUrl, argv.https));

(async function () {
    if (argv.https) {
        const httpsServer = https.createServer(await getCredentials(argv.host, argv.port), app);
        httpsServer.listen(argv.port, argv.host, undefined, () => {
            console.log(chalk.green(`Listening on https://${argv.host}:${argv.port}`));
        });
    } else {
        app.listen(argv.port, argv.host, () => {
            console.log(chalk.green(`Listening on http://${argv.host}:${argv.port}`));
        });
    }
})();
