module.exports = (serviceUrl = "https://analytics.ytica.com", https = false) => ({
    target: serviceUrl,
    changeOrigin: true,
    cookieDomainRewrite: "localhost",
    onProxyReq: (proxyReq) => {
        if (proxyReq.getHeader("origin")) {
            proxyReq.setHeader("origin", serviceUrl);
        }
    },
    onProxyRes: (proxyRes, req) => {
        let cookies = proxyRes.headers["set-cookie"];
        if (cookies) {
            if (!https) {
                cookies = cookies.map((c) => c.replace("; Secure", "")).map((c) => c.replace("; SameSite=None", ""));
            }
            // When viewing a report on the legacy dashboard, the GD app would display an error message
            // about cookies not being enabled. I was able to contact their support and they shared the mechanism
            // which determines if cookies are enabled or not. First, they try to create the cookie of this name and
            // value and then check if it exists. If they cannot read it, they determine the cookies are not enabled.
            // For some reason the creation part fails when running behind a proxy (domain mismatch? idk)
            // The solution is to send this cookie to the browser during the login, which means the cookie will
            // be attached to all the requests in the future. The GD then tries to read this value,
            // which it will be able to do and determine the cookies are enabled.
            cookies.push("GDC-check=I have cookies; Path=/");
        }
        proxyRes.headers["set-cookie"] = cookies;
    }
});
